---
title: 엑심베이 해외결제 서비스 이용안내
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 해외결제
seo:
  title: 엑심베이 해외결제 서비스 이용안내
  description: >-
    엑심베이의 해외카드결제 서비스를 통한 해외결제 이용방법 안내드립니다. 엑심베이의 연동가이드부터 가입방법, 결제수단, 지원언어, 결제통화,
    정산통화, 결제수단별 수수료, 가입비, 추가지원, 정산주기 등 자세한 정보를 확인해보세요.
  keywords:
    - 해외결제
tags:
  - 엑심베이
  - 해외결제
pgCompanies:
  - 엑심베이
searchTags:
  - 엑심베이
  - DCC
  - 해외결제
  - 엑심베이 해외결제
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="엑심베이를 통한 해외결제 이용방법 안내드립니다." />

### **엑심베이 해외카드결제 서비스 이용안내**

<Callout content="1. 해외사업자는 지원되지 않습니다(한국 사업자만 이용가능)
2. Razer Merchant Services(구 Molpay) : 해당 결제사 정책으로 인해 2023.11.24 부로 서비스가 영구 종료 되었습니다.
3 Yoomoney(러시아) : 러시아-우크라이나 이슈로 중단 되었습니다.
4. eContext(일본) : eContext 정책상 법인사업자만 이용이 가능한 수단 입니다.(개인사업자 이용 불가)" title="참고사항" icon="💡" />



- **지원 결제수단**
  - VISA/MASTER/JCB/Amex(해외 발행 글로벌 카드), Alipay , Wechat(PC) , eContext ,Unionpay

* **통화**
  - 결제 통화
    - 엑심베이가 지원하는 통화(화폐 단위) 범위안에서 결제 가능(KRW 가능)
      - [엑심베이 지원 통화 보러가기↗](https://support.eximbay.com/hc/ko/articles/360052304233-%EC%A7%80%EC%9B%90-%EA%B0%80%EB%8A%A5%ED%95%9C-%EA%B2%B0%EC%A0%9C-%ED%86%B5%ED%99%94%EB%8A%94-%EC%96%B4%EB%96%BB%EA%B2%8C-%EB%90%98%EB%82%98%EC%9A%94)
  - 정산 통화 : KRW / USD
    - 원화정산 : 송금수수료 없음 / 외화정산 : KEB 하나은행외 외화계좌 이체시 건당 4 USD 부과

- **수수료**
  - VISA/MASTER/JCB/Amex : 4.50% (해외 발행 글로벌 카드)
  - Alipay : 2.90%
  - Wechat (PC) : 2.80%
  - eContext (일본) : 4.50%

* **정산주기** : 계약이후 정확한 정산주기가 설정되며, 보통 일주일간의 거래를 3주후에 정산하는 방식으로 진행됩니다.

- **추가 지원사항** : 다국통화 승인 결제 서비스( DCC = Dynamic Currency Conversion ) 지원

* **결제요청 한도**
  - 최대 건/월 한도 : USD 1,000 제공 
  - 동일 카드에 대한 월간 최대 결제 횟수 : 5회/월
  - 동일카드 건당 최대승인한도 : USD 1,000
  - 동일카드 월별 최대승인한도 : USD 1,000  

- **결제 요청 금액 한도 상향 요청 방법**
  - 계약 이후 6개월 정도의 거래 모니터링을 통하여 보증보험 증액 여부 판단.
  - 월 매출 예상 금액을 넘을 경우   
    - 보증보험 증액 / 정산대금 지급 보류를 통한 현금 담보 전환

* **최소 결제 요청 가능한 금액**
  - 원화 : 100원 이상 / 달러 : 0.1달러 이상 / 엔화 100엔 이상

- **정산환율**
  - 결제통화와 정산통화가 다른 경우 적용되는 정산 환율
    - 원화 → 외화인 경우 전신환 송금 보내실 때 환율적용
    - 외화 → 원화인 경우 전신환 송금 받으실 때 환율적용
    - 외화 → 외화인 경우 (ex. USD → JPY ) USD 받으실 때(파실 때) 환율 ÷ JPY 보내실 때(살 때) 환율적용
  - 원화(KRW) 외 기타 통화로 결제 후 원화(KRW)로 정산받는 경우 적용되는 환율
    - VISA / MASTER / JCB : 고객이 결제하는 시점의 실시간 수표매입률 적용되어 KRW 로 매입 -> 해당 KRW 금액에서 결제수수료(KRW) 와 부가세(KRW) 차감 후 정산됩니다. \
      승인 시에 환율(실시간 수표매입률)이 적용되나, 정산 시에는 환율이 개입되지 않습니다. 
    - VISA / MASTER / JCB 외 기타 결제수단 : 송금예정일 -3일자, 하나은행 '전신환 송금받으실 때' 최종 고시 환율\
      ex) 2020-08-21(금)에 정산 예정인 거래대금은, 아래 환율이 적용됩니다.\
      \- 적용 환율일자 : 2020-08-21일자로부터 \
      \- 3영업일인 2020-08-18일\
      \- 환율 종류 : 하나은행 '전신환 송금받으실 때' 최종 고시 환율

<Callout title="엑심베이 연동가이드 보러가기↗" />
